@@ -3,13 +3,19 @@
 
 from daytona_api_client import SandboxState, SessionExecuteResponse
 
+from ._async.computer_use import (
+    AsyncComputerUse,
+    AsyncDisplay,
+    AsyncKeyboard,
+    AsyncMouse,
+    AsyncScreenshot,
+    ScreenshotOptions,
+    ScreenshotRegion,
+)
 from ._async.daytona import AsyncDaytona
 from ._async.sandbox import AsyncSandbox
 from ._sync.daytona import Daytona
 from ._sync.sandbox import Sandbox
-
-# Create deprecated aliases with proper warnings
-from ._utils.deprecation import deprecated_alias
 from .common.charts import (
     BarChart,
     BoxAndWhiskerChart,
@@ -60,6 +66,13 @@ __all__ = [
     "VolumeMount",
     "AsyncDaytona",
     "AsyncSandbox",
+    "AsyncComputerUse",
+    "AsyncMouse",
+    "AsyncKeyboard",
+    "AsyncScreenshot",
+    "AsyncDisplay",
+    "ScreenshotRegion",
+    "ScreenshotOptions",
     "Image",
     "CreateSandboxBaseParams",
     "CreateSandboxFromImageParams",
