@@ -2,11 +2,12 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import asyncio
+import time
 from typing import Dict, Optional
 
 from daytona_api_client_async import PortPreviewUrl
 from daytona_api_client_async import Sandbox as SandboxDto
-from daytona_api_client_async import SandboxApi, ToolboxApi
+from daytona_api_client_async import SandboxApi, SshAccessDto, SshAccessValidationDto, ToolboxApi
 from pydantic import ConfigDict, PrivateAttr
 
 from .._utils.errors import intercept_errors
@@ -47,11 +48,14 @@ class AsyncSandbox(SandboxDto):
         backup_created_at (str): When the backup was created.
         auto_stop_interval (int): Auto-stop interval in minutes.
         auto_archive_interval (int): Auto-archive interval in minutes.
+        auto_delete_interval (int): Auto-delete interval in minutes.
         runner_domain (str): Domain name of the Sandbox runner.
         volumes (List[str]): Volumes attached to the Sandbox.
         build_info (str): Build information for the Sandbox if it was created from dynamic build.
         created_at (str): When the Sandbox was created.
         updated_at (str): When the Sandbox was last updated.
+        network_block_all (bool): Whether to block all network access for the Sandbox.
+        network_allow_list (str): Comma-separated list of allowed CIDR network addresses for the Sandbox.
     """
 
     _fs: AsyncFileSystem = PrivateAttr()
@@ -212,9 +216,11 @@ class AsyncSandbox(SandboxDto):
             print("Sandbox started successfully")
             ```
         """
+        start_time = time.time()
         sandbox = await self._sandbox_api.start_sandbox(self.id, _request_timeout=timeout or None)
         self.__process_sandbox_dto(sandbox)
-        await self.wait_for_sandbox_start()
+        time_elapsed = time.time() - start_time
+        await self.wait_for_sandbox_start(timeout=max(0.001, timeout - time_elapsed) if timeout else timeout)
 
     @intercept_errors(message_prefix="Failed to stop sandbox: ")
     @with_timeout(
@@ -238,9 +244,11 @@ class AsyncSandbox(SandboxDto):
             print("Sandbox stopped successfully")
             ```
         """
+        start_time = time.time()
         await self._sandbox_api.stop_sandbox(self.id, _request_timeout=timeout or None)
         await self.refresh_data()
-        await self.wait_for_sandbox_stop()
+        time_elapsed = time.time() - start_time
+        await self.wait_for_sandbox_stop(timeout=max(0.001, timeout - time_elapsed) if timeout else timeout)
 
     @intercept_errors(message_prefix="Failed to remove sandbox: ")
     async def delete(self, timeout: Optional[float] = 60) -> None:
@@ -299,6 +307,7 @@ class AsyncSandbox(SandboxDto):
         """Waits for the Sandbox to reach the 'stopped' state. Polls the Sandbox status until it
         reaches the 'stopped' state, encounters an error or times out. It will wait up to 60 seconds
         for the Sandbox to stop.
+        Treats destroyed as stopped to cover ephemeral sandboxes that are automatically deleted after stopping.
 
         Args:
             timeout (Optional[float]): Maximum time to wait in seconds. 0 means no timeout. Default is 60 seconds.
@@ -306,7 +315,7 @@ class AsyncSandbox(SandboxDto):
         Raises:
             DaytonaError: If timeout is negative. If Sandbox fails to stop or times out.
         """
-        while self.state != "stopped":
+        while self.state not in ["stopped", "destroyed"]:
             try:
                 await self.refresh_data()
 
@@ -367,9 +376,9 @@ class AsyncSandbox(SandboxDto):
         Example:
             ```python
             # Auto-archive after 1 hour
-            sandbox.set_autoarchive_interval(60)
+            sandbox.set_auto_archive_interval(60)
             # Or use the maximum interval
-            sandbox.set_autoarchive_interval(0)
+            sandbox.set_auto_archive_interval(0)
             ```
         """
         if not isinstance(interval, int) or interval < 0:
@@ -377,6 +386,30 @@ class AsyncSandbox(SandboxDto):
         await self._sandbox_api.set_auto_archive_interval(self.id, interval)
         self.auto_archive_interval = interval
 
+    @intercept_errors(message_prefix="Failed to set auto-delete interval: ")
+    async def set_auto_delete_interval(self, interval: int) -> None:
+        """Sets the auto-delete interval for the Sandbox.
+
+        The Sandbox will automatically delete after being continuously stopped for the specified interval.
+
+        Args:
+            interval (int): Number of minutes after which a continuously stopped Sandbox will be auto-deleted.
+                Set to negative value to disable auto-delete. Set to 0 to delete immediately upon stopping.
+                By default, auto-delete is disabled.
+
+        Example:
+            ```python
+            # Auto-delete after 1 hour
+            sandbox.set_auto_delete_interval(60)
+            # Or delete immediately upon stopping
+            sandbox.set_auto_delete_interval(0)
+            # Or disable auto-delete
+            sandbox.set_auto_delete_interval(-1)
+            ```
+        """
+        await self._sandbox_api.set_auto_delete_interval(self.id, interval)
+        self.auto_delete_interval = interval
+
     @intercept_errors(message_prefix="Failed to get preview link: ")
     async def get_preview_link(self, port: int) -> PortPreviewUrl:
         """Retrieves the preview link for the sandbox at the specified port. If the port is closed,
@@ -410,6 +443,33 @@ class AsyncSandbox(SandboxDto):
         await self._sandbox_api.archive_sandbox(self.id)
         await self.refresh_data()
 
+    @intercept_errors(message_prefix="Failed to create SSH access: ")
+    async def create_ssh_access(self, expires_in_minutes: Optional[int] = None) -> SshAccessDto:
+        """Creates an SSH access token for the sandbox.
+
+        Args:
+            expires_in_minutes (Optional[int]): The number of minutes the SSH access token will be valid for.
+        """
+        return (await self._sandbox_api.create_ssh_access(self.id, expires_in_minutes=expires_in_minutes)).data
+
+    @intercept_errors(message_prefix="Failed to revoke SSH access: ")
+    async def revoke_ssh_access(self, token: str) -> None:
+        """Revokes an SSH access token for the sandbox.
+
+        Args:
+            token (str): The token to revoke.
+        """
+        await self._sandbox_api.revoke_ssh_access(self.id, token)
+
+    @intercept_errors(message_prefix="Failed to validate SSH access: ")
+    async def validate_ssh_access(self, token: str) -> SshAccessValidationDto:
+        """Validates an SSH access token for the sandbox.
+
+        Args:
+            token (str): The token to validate.
+        """
+        return (await self._sandbox_api.validate_ssh_access(token)).data
+
     async def __get_root_dir(self) -> str:
         if not self._root_dir:
             self._root_dir = await self.get_user_root_dir()
@@ -434,8 +494,11 @@ class AsyncSandbox(SandboxDto):
         self.backup_created_at = sandbox_dto.backup_created_at
         self.auto_stop_interval = sandbox_dto.auto_stop_interval
         self.auto_archive_interval = sandbox_dto.auto_archive_interval
+        self.auto_delete_interval = sandbox_dto.auto_delete_interval
         self.runner_domain = sandbox_dto.runner_domain
         self.volumes = sandbox_dto.volumes
         self.build_info = sandbox_dto.build_info
         self.created_at = sandbox_dto.created_at
         self.updated_at = sandbox_dto.updated_at
+        self.network_block_all = sandbox_dto.network_block_all
+        self.network_allow_list = sandbox_dto.network_allow_list
